#!/usr/bin/env python3
# coding=utf-8

"""
@author: guoyanfeng
@software: PyCharm
@time: 18-12-26 下午3:32
"""

from collections import MutableMapping, MutableSequence
from typing import Dict, List, Union

__all__ = ("_verify_message", "under2camel")


def under2camel(under_string: str) -> str:
    """Converts an underscored string to camelcased. Useful for turning a
    function name into a class name.

    >>> under2camel('complex_tokenizer')
    'ComplexTokenizer'
    """
    return ''.join(w.capitalize() or '_' for w in under_string.split('_'))


def _verify_message(src_message: Dict[int, Dict[str, str]], message: Union[List[Dict[str, str]], Dict[str, str]]
                    ) -> Dict[int, Dict[str, str]]:
    """
    对用户提供的message进行校验
    Args:
        src_message: 默认提供的消息内容
        message: 指定的消息内容
    Returns:

    """
    src_message = dict(src_message)
    message = message if isinstance(message, MutableSequence) else [message]
    required_field = {"msg_code", "msg_zh", "msg_en"}

    for msg in message:
        if isinstance(msg, MutableMapping):
            if set(msg.keys()).intersection(required_field) == required_field and msg["msg_code"] in src_message:
                src_message[int(msg["msg_code"])].update(msg)
    return src_message
